Bump version
[libdcp.git] / src / dcp.h
index 8dd7a412a2287f87319112ab6e29c75c557553d2..635a972d65a07c3e961abaacd21741effb043a02 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
 #include <string>
 #include <vector>
 #include <boost/shared_ptr.hpp>
-#include <sigc++/sigc++.h>
+#include <boost/signals2.hpp>
 #include "types.h"
+#include "certificates.h"
 
 namespace xmlpp {
-       class Node;
+       class Document;
+       class Element;
 }
 
 /** @brief Namespace for everything in libdcp */
@@ -43,131 +45,115 @@ class PictureAsset;
 class SoundAsset;
 class SubtitleAsset;
 class Reel;
+class CPL;
+class XMLMetadata;
+class Signer;
+class KDM;
 
-/** @class DCP dcp.h libdcp/dcp.h
+namespace parse {
+       class AssetMap;
+}
+
+/** @class DCP
  *  @brief A class to create or read a DCP.
  */
        
-class DCP
+class DCP : public boost::noncopyable
 {
 public:
-       /** Construct a DCP.
-        *
-        *  This is for making a new DCP that you are going to add assets to.
+       /** Construct a DCP.  You can pass an existing DCP's directory
+        *  as the parameter, or a non-existant folder to create a new
+        *  DCP in.
         *
-        *  @param directory Directory to write files to.
-        *  @param name Name.
-        *  @param content_kind Content kind.
-        *  @param fps Frames per second.
-        *  @param length Length in frames.
+        *  @param directory Directory containing the DCP's files.
         */
-       DCP (std::string directory, std::string name, ContentKind content_kind, int fps, int length);
+       DCP (boost::filesystem::path directory);
 
-       /** Construct a DCP object for an existing DCP.
+       void read (bool require_mxfs = true);
+
+       /** Read an existing DCP's assets.
         *
         *  The DCP's XML metadata will be examined, and you can then look at the contents
         *  of the DCP.
-        *
-        *  @param directory Existing DCP's directory.
-        *  @param read_mxfs true to read MXF files; setting to false can be useful for testing, but
-        *  normally it should be set to true.
         */
-       DCP (std::string directory, bool read_mxfs = true);
+       void read_assets ();
 
-       void add_reel (boost::shared_ptr<const Reel> reel);
+       void read_cpls (bool require_mxfs = true);
 
        /** Write the required XML files to the directory that was
         *  passed into the constructor.
         */
-       void write_xml () const;
+       void write_xml (bool interop, XMLMetadata const &, boost::shared_ptr<const Signer> signer = boost::shared_ptr<const Signer> ()) const;
 
-       /** @return the DCP's name, as will be presented on projector
-        *  media servers and theatre management systems.
+       /** Compare this DCP with another, according to various options.
+        *  @param other DCP to compare this one to.
+        *  @param options Options to define what "equality" means.
+        *  @return true if the DCPs are equal according to EqualityOptions, otherwise false.
         */
-       std::string name () const {
-               return _name;
-       }
+       bool equals (DCP const & other, EqualityOptions options, boost::function<void (NoteType, std::string)> note) const;
 
-       /** @return the type of the content, used by media servers
-        *  to categorise things (e.g. feature, trailer, etc.)
+       /** Add a CPL to this DCP.
+        *  @param cpl CPL to add.
         */
-       ContentKind content_kind () const {
-               return _content_kind;
-       }
+       void add_cpl (boost::shared_ptr<CPL> cpl);
 
-       /** @return the number of frames per second */
-       int frames_per_second () const {
-               return _fps;
+       /** @return The list of CPLs in this DCP */
+       std::list<boost::shared_ptr<CPL> > cpls () const {
+               return _cpls;
        }
 
-       /** @return the length in frames */
-       int length () const {
-               return _length;
-       }
+       /** Add another DCP as a source of assets for this DCP.  This should be called before
+        *  ::read() on the DCP that needs the extra assets.  For example
+        *
+        *  DCP original_version ("my_dcp_OV");
+        *  DCP supplemental ("my_dcp_VF");
+        *  supplemental.add_assets_from (original_version);
+        *  supplemental.read ();
+        */
+       void add_assets_from (libdcp::DCP const &);
 
-       std::list<boost::shared_ptr<const Reel> > reels () const {
-               return _reels;
-       }
+       bool encrypted () const;
 
-       /** Compare this DCP with another, according to various options.
-        *  @param other DCP to compare this one to.
-        *  @param options Options to define just what "equality" means.
-        *  @return An empty list if the DCPs are equal; otherwise a list of messages
-        *  which explain the ways in which they differ.
-        */
-       std::list<std::string> equals (DCP const & other, EqualityOptions options) const;
+       void add_kdm (KDM const &);
 
        /** Emitted with a parameter between 0 and 1 to indicate progress
         *  for long jobs.
         */
-       sigc::signal1<void, float> Progress;
+       boost::signals2::signal<void (float)> Progress;
 
 private:
 
-       /** Write the CPL file.
-        *  @param cpl_uuid UUID to use.
-        *  @return CPL pathname.
-        */
-       std::string write_cpl (std::string cpl_uuid) const;
-
        /** Write the PKL file.
         *  @param pkl_uuid UUID to use.
-        *  @param cpl_uuid UUID of the CPL file.
-        *  @param cpl_digest SHA digest of the CPL file.
-        *  @param cpl_length Length of the CPL file in bytes.
         */
-       std::string write_pkl (std::string pkl_uuid, std::string cpl_uuid, std::string cpl_digest, int cpl_length) const;
+       std::string write_pkl (std::string pkl_uuid, bool, XMLMetadata const &, boost::shared_ptr<const Signer>) const;
        
        /** Write the VOLINDEX file */
        void write_volindex () const;
 
        /** Write the ASSETMAP file.
-        *  @param cpl_uuid UUID of our CPL.
-        *  @param cpl_length Length of our CPL in bytes.
         *  @param pkl_uuid UUID of our PKL.
         *  @param pkl_length Length of our PKL in bytes.
         */
-       void write_assetmap (std::string cpl_uuid, int cpl_length, std::string pkl_uuid, int pkl_length) const;
+       void write_assetmap (std::string pkl_uuid, int pkl_length, bool, XMLMetadata const &) const;
+
+       /** @return Assets in all the CPLs in this DCP */
+       std::list<boost::shared_ptr<const Asset> > assets () const;
 
        struct Files {
-               std::string cpl;
+               std::list<std::string> cpls;
                std::string pkl;
                std::string asset_map;
-               std::list<std::string> subtitles;
        };
 
+       Files _files;
+
        /** the directory that we are writing to */
-       std::string _directory;
-       /** the name of the DCP */
-       std::string _name;
-       /** the content kind of the DCP */
-       ContentKind _content_kind;
-       /** frames per second */
-       int _fps;
-       /** length in frames */
-       int _length;
-       /** reels */
-       std::list<boost::shared_ptr<const Reel> > _reels;
+       boost::filesystem::path _directory;
+       /** our CPLs */
+       std::list<boost::shared_ptr<CPL> > _cpls;
+
+       std::list<PathAssetMap> _asset_maps;
 };
 
 }